==> haskell-cheapskate-0.1.1.2-819-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-BsPiz0eu1OvJzyr9SquaI0
key:                  cheapskate-0.1.1.2-BsPiz0eu1OvJzyr9SquaI0
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  4c9414f65b64e1a32e4cd219cd5a9e94
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cheapskate
hs-libraries:         HScheapskate-0.1.1.2-BsPiz0eu1OvJzyr9SquaI0
depends:
    base-4.17.2.1 blaze-html-0.9.2.0-Hmx0qDwpXdTINSADNpvYjl
    containers-0.6.7 data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM
    deepseq-1.4.8.0 mtl-2.2.2 syb-0.7.3-Lap6GPARkRXCVbqA2faY6P
    text-2.0.2 uniplate-1.6.13-3A7tFnZj2gFIUf6NkBSGEF
    xss-sanitize-0.3.7.2-8iCHVrFhaMDFSOKMTBRAvC

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.1.2-820-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-DwpUjg0JT1uBpLkwpHghi0
key:                  cheapskate-0.1.1.2-DwpUjg0JT1uBpLkwpHghi0
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  0b77672d6d8528b45b540ba2782a2b82
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cheapskate
hs-libraries:         HScheapskate-0.1.1.2-DwpUjg0JT1uBpLkwpHghi0
depends:
    base-4.17.2.1 blaze-html-0.9.2.0-LTAcRvwA4RX5X1Di6KFyT1
    containers-0.6.7 data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM
    deepseq-1.4.8.0 mtl-2.2.2 syb-0.7.3-82kecYkSnotJhXSs3T6xq0
    text-2.0.2 uniplate-1.6.13-4DBmZGG2z4KLgAHzOTo8OL
    xss-sanitize-0.3.7.2-D77ZOZXrMMhLkjHM9FaJVu

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
